aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMohammed Attia <skeuomorf@gmail.com>2014-03-04 00:08:20 +0200
committerMohammed Attia <skeuomorf@gmail.com>2014-03-04 00:08:20 +0200
commita4e95af4b7f871822d1e9af9aa968de0b45e42e4 (patch)
treefe26728ee3b97ec56094388d65f99c20199ca107
parentc2ea0fb9694b663faf13fcf418062706ffca8054 (diff)
downloadcryptography-a4e95af4b7f871822d1e9af9aa968de0b45e42e4.tar.gz
cryptography-a4e95af4b7f871822d1e9af9aa968de0b45e42e4.tar.bz2
cryptography-a4e95af4b7f871822d1e9af9aa968de0b45e42e4.zip
More accurate docstring
-rw-r--r--cryptography/hazmat/primitives/interfaces.py25
1 files changed, 14 insertions, 11 deletions
diff --git a/cryptography/hazmat/primitives/interfaces.py b/cryptography/hazmat/primitives/interfaces.py
index a8956b85..bfe9c1da 100644
--- a/cryptography/hazmat/primitives/interfaces.py
+++ b/cryptography/hazmat/primitives/interfaces.py
@@ -291,20 +291,23 @@ class DSAParams(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def modulus(self):
"""
The prime modulus that's used in generating the DSA keypair.
"""
@abc.abstractproperty
def subgroup_order(self):
"""
The subgroup order that's used in generating the DSA keypair
- by the generator.
+ by the generator and used in the DSA signing and verification
+ processes.
"""
@abc.abstractproperty
def generator(self):
"""
- The generator that is used in generating the DSA keypair.
+ The generator that is used in generating the DSA keypair and used
+ in the DSA signing and verification processes."
"""
@abc.abstractmethod
@@ -316,23 +319,23 @@ class DSAParams(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def p(self):
"""
- The prime modulus that's used in generating the DSA keypair.
- Alias for modulus.
+ The prime modulus that's used in generating the DSA keypair and used
+ in the DSA signing and verification processes. Alias for modulus.
"""
@abc.abstractproperty
def q(self):
"""
The subgroup order that's used in generating the DSA keypair
- by the generator.
- Alias for subgroup_order.
+ by the generator and used in the DSA signing and verification
+ processes. Alias for subgroup_order.
"""
@abc.abstractproperty
def g(self):
"""
- The generator that is used in generating the DSA keypair.
- Alias for generator.
+ The generator that is used in generating the DSA keypair and used
+ in the DSA signing and verification processes. Alias for generator.
"""
@@ -358,7 +361,7 @@ class DSAPrivateKey(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def y(self):
"""
- The integer value of y.
+ The public key.
"""
@abc.abstractproperty
@@ -372,7 +375,7 @@ class DSAPublicKey(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def y(self):
"""
- The integer value of y.
+ The public key.
"""
@abc.abstractproperty
@@ -291,20 +291,23 @@ class DSAParams(six.with_metaclass(abc.ABCMeta)):
def modulus(self):
"""
- The prime modulus that's used in generating the DSA keypair.
+ The prime modulus that's used in generating the DSA keypair and used
+ in the DSA signing and verification processes.
"""